@@ -5,7 +5,13 @@ import contextlib
 import copy
 import typing as t
 
-from globus_sdk import AuthClient, AuthLoginClient, GlobusSDKUsageError, Scope
+from globus_sdk import (
+    AuthClient,
+    AuthLoginClient,
+    GlobusSDKUsageError,
+    IDTokenDecoder,
+    Scope,
+)
 from globus_sdk._types import ScopeCollectionType, UUIDLike
 from globus_sdk.authorizers import GlobusAuthorizer
 from globus_sdk.gare import GlobusAuthorizationParameters
@@ -97,6 +103,11 @@ class GlobusApp(metaclass=abc.ABCMeta):
             scope_requirements=self._scope_requirements,
         )
 
+        # setup an ID Token Decoder based on config; build one if it was not provided
+        self._id_token_decoder = self._initialize_id_token_decoder(
+            app_name=self.app_name, config=self.config, login_client=self._login_client
+        )
+
         # initialize our authorizer factory
         self._initialize_authorizer_factory()
         self._authorizer_factory_initialized = True
@@ -239,6 +250,34 @@ class GlobusApp(metaclass=abc.ABCMeta):
             f"TokenStorage, TokenStorageProvider, or a supported string value."
         )
 
+    def _initialize_id_token_decoder(
+        self, *, app_name: str, config: GlobusAppConfig, login_client: AuthLoginClient
+    ) -> IDTokenDecoder:
+        """
+        Create an IDTokenDecoder or use the one provided via config, and set it on
+        the token storage adapters.
+
+        It is only set on inner storage if the decoder was not already set, so a
+        non-null value won't be overwritten.
+
+        This must run near the end of app initialization, when the `_token_storage`
+        (inner) and `token_storage` (validating storage, outer) storages have both
+        been initialized.
+        """
+        if isinstance(self.config.id_token_decoder, IDTokenDecoder):
+            id_token_decoder: IDTokenDecoder = self.config.id_token_decoder
+        else:
+            id_token_decoder = self.config.id_token_decoder.for_globus_app(
+                app_name=app_name,
+                config=config,
+                login_client=login_client,
+            )
+        if self._token_storage.id_token_decoder is None:
+            self._token_storage.id_token_decoder = id_token_decoder
+        self.token_storage.id_token_decoder = id_token_decoder
+
+        return id_token_decoder
+
     @abc.abstractmethod
     def _initialize_authorizer_factory(self) -> None:
         """
