@@ -12,8 +12,8 @@ from .._common import stringify_requested_scopes
 from ..flow_managers import GlobusAuthorizationCodeFlowManager
 from ..response import (
     GetIdentitiesResponse,
+    OAuthClientCredentialsResponse,
     OAuthDependentTokenResponse,
-    OAuthTokenResponse,
 )
 from .base_login_client import AuthLoginClient
 
@@ -109,7 +109,7 @@ class ConfidentialAppAuthClient(AuthLoginClient):
     def oauth2_client_credentials_tokens(
         self,
         requested_scopes: ScopeCollectionType | None = None,
-    ) -> OAuthTokenResponse:
+    ) -> OAuthClientCredentialsResponse:
         r"""
         Perform an OAuth2 Client Credentials Grant to get access tokens which
         directly represent your client and allow it to act on its own
@@ -132,7 +132,8 @@ class ConfidentialAppAuthClient(AuthLoginClient):
         log.info("Fetching token(s) using client credentials")
         requested_scopes_string = stringify_requested_scopes(requested_scopes)
         return self.oauth2_token(
-            {"grant_type": "client_credentials", "scope": requested_scopes_string}
+            {"grant_type": "client_credentials", "scope": requested_scopes_string},
+            response_class=OAuthClientCredentialsResponse,
         )
 
     def oauth2_start_flow(
