@@ -2,14 +2,8 @@ from __future__ import annotations
 
 import datetime
 import logging
-import sys
 import typing as t
 
-if sys.version_info >= (3, 8):
-    from typing import Literal
-else:
-    from typing_extensions import Literal
-
 from globus_sdk import exc, utils
 from globus_sdk._types import UUIDLike
 
@@ -17,8 +11,7 @@ if t.TYPE_CHECKING:
     import globus_sdk
 
 log = logging.getLogger(__name__)
-_StrSyncLevel = Literal["exists", "size", "mtime", "checksum"]
-_sync_level_dict: dict[_StrSyncLevel, int] = {
+_sync_level_dict: dict[t.Literal["exists", "size", "mtime", "checksum"], int] = {
     "exists": 0,
     "size": 1,
     "mtime": 2,
@@ -26,7 +19,9 @@ _sync_level_dict: dict[_StrSyncLevel, int] = {
 }
 
 
-def _parse_sync_level(sync_level: _StrSyncLevel | int) -> int:
+def _parse_sync_level(
+    sync_level: t.Literal["exists", "size", "mtime", "checksum"] | int
+) -> int:
     """
     Map sync_level strings to known int values
 
@@ -174,7 +169,9 @@ class TransferData(utils.PayloadWrapper):
         *,
         label: str | None = None,
         submission_id: UUIDLike | None = None,
-        sync_level: _StrSyncLevel | int | None = None,
+        sync_level: (
+            int | None | t.Literal["exists", "size", "mtime", "checksum"]
+        ) = None,
         verify_checksum: bool = False,
         preserve_timestamp: bool = False,
         encrypt_data: bool = False,
@@ -335,8 +332,10 @@ class TransferData(utils.PayloadWrapper):
         self,
         name: str,
         *,
-        method: Literal["include", "exclude"] = "exclude",
-        type: None | Literal["file", "dir"] = None,  # pylint: disable=redefined-builtin
+        method: t.Literal["include", "exclude"] = "exclude",
+        type: (  # pylint: disable=redefined-builtin
+            None | t.Literal["file", "dir"]
+        ) = None,
     ) -> None:
         """
         Add a filter rule to the transfer document.
