@@ -2,9 +2,12 @@ from __future__ import annotations
 
 import collections
 import collections.abc
+import functools
 import hashlib
 import os
+import platform
 import sys
+import textwrap
 import typing as t
 import uuid
 from base64 import b64encode
@@ -70,36 +73,19 @@ def b64str(s: str) -> str:
     return b64encode(s.encode("utf-8")).decode("utf-8")
 
 
-def check_uuid(s: UUIDLike, *, name: str) -> t.Literal[True]:
+def get_nice_hostname() -> str | None:
     """
-    Raise an error if the input is not a UUID
+    Get the current hostname, with the following added behavior:
 
-    :param s: the UUID|str value
-    :param name: the name for this value to use in error messages
-
-    :raises TypeError: if the input is not a UUID|str
-    :raises ValueError: if the input is a non-UUID str
-
-    Example usage:
-
-    .. code-block:: python
-
-        def frob_it(collection_id: UUIDLike) -> Frob:
-            utils.check_uuid(collection_id, name="collection_id")
-            return Frob(collection_id)
+    - if it ends in '.local', strip that suffix, as this is a frequent macOS behavior
+      'DereksCoolMacbook.local' -> 'DereksCoolMacbook'
 
+    - if the hostname is undiscoverable, return None
     """
-    if isinstance(s, uuid.UUID):
-        return True
-    elif not isinstance(s, str):
-        raise TypeError(f"'{name}' must be a UUID or str (value='{s}')")
-
-    try:
-        uuid.UUID(s)
-    except ValueError as e:
-        raise ValueError(f"'{name}' must be a valid UUID (value='{s}')") from e
-
-    return True
+    name = platform.node()
+    if name.endswith(".local"):
+        return name[: -len(".local")]
+    return name or None
 
 
 def slash_join(a: str, b: str | None) -> str:
@@ -292,3 +278,48 @@ else:
     def classproperty(func: t.Callable[[T], R]) -> _classproperty[T, R]:
         # type cast to convert instance method to class method
         return _classproperty(t.cast(t.Callable[[t.Type[T]], R], func))
+
+
+@functools.lru_cache(maxsize=None)
+def read_sphinx_params(docstring: str) -> tuple[str, ...]:
+    """
+    Given a docstring, extract the `:param:` declarations into a tuple of strings.
+
+    :param docstring: The ``__doc__`` to parse, as it appeared on the original object
+
+    Params start with `:param ...` and end
+    - at the end of the string
+    - at the next param
+    - when a non-indented, non-param line is found
+
+    Whitespace lines within a param doc are supported.
+
+    All produced param strings are dedented.
+    """
+    docstring = textwrap.dedent(docstring)
+
+    result: list[str] = []
+    current: list[str] = []
+    for line in docstring.splitlines():
+        if not current:
+            if line.startswith(":param"):
+                current = [line]
+            else:
+                continue
+        else:
+            # a new param -- flush the current one and restart
+            if line.startswith(":param"):
+                result.append("\n".join(current).strip())
+                current = [line]
+            # a continuation line for the current param (indented)
+            # or a blank line -- it *could* be a continuation of param doc (include it)
+            elif line != line.lstrip() or not line:
+                current.append(line)
+            # otherwise this is a populated line, not indented, and without a `:param`
+            # start -- stop looking for more param doc
+            else:
+                break
+    if current:
+        result.append("\n".join(current).strip())
+
+    return tuple(result)
